"""Top-level package for beobench."""

__author__ = """rdnfn"""
__email__ = "-"
__version__ = "0.2.0"

from beobench.utils import restart
